Package: planet
Title: Placental DNA methylation analysis tools
Version: 1.20.0
Authors@R: 
    c(person("Victor", "Yuan", email = "victor.2wy@gmail.com",
            role = c("aut", "cre")),
      person(c("Wendy", "P."), "Robinson",
            role = c("aut", "ctb")),
      person("Icíar", "Fernández-Boyano", email = "iciarfernandez@outlook.com",
            role = c("aut", "ctb")))
URL: http://github.com/wvictor14/planet, http://victoryuan.com/planet/
BugReports: http://github.com/wvictor14/planet/issues
Description: This package contains R functions to predict biological variables
    to from placnetal DNA methylation data generated from infinium arrays. This 
    includes inferring ethnicity/ancestry, gestational age, and cell composition
    from placental DNA methylation array (450k/850k) data.
Depends: R (>= 4.3)
Imports: methods, tibble, magrittr, dplyr
Suggests: ExperimentHub, mixOmics, ggplot2, testthat, tidyr, scales,
        minfi, EpiDISH, knitr, rmarkdown
License: GPL-2
Encoding: UTF-8
LazyData: false
RoxygenNote: 7.3.2
VignetteBuilder: knitr
biocViews: Software, DifferentialMethylation, Epigenetics, Microarray,
        MethylationArray, DNAMethylation, CpGIsland
Roxygen: list(markdown = TRUE)
git_url: https://git.bioconductor.org/packages/planet
git_branch: RELEASE_3_23
git_last_commit: 2e51242
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:53:34 UTC; biocbuild
Author: Victor Yuan [aut, cre],
  Wendy P. Robinson [aut, ctb],
  Icíar Fernández-Boyano [aut, ctb]
Maintainer: Victor Yuan <victor.2wy@gmail.com>
