# data
This directory contains static external resources used by the codebase.

## GeoJSON Schemas

### Files

* `Feature.json`

### Description

These files were generated by cloning and building
[geojson/schema](https://github.com/geojson/schema)
([commit](https://github.com/geojson/schema/commit/ed4bc7b05e6d6751be12b867ca89a30d6aba7650)). These can also be accessed from [geojson.org](https://geojson.org/).
