---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: proposal
assignees: ''

---

**Is your feature request related to a problem? Please describe.**


**Describe the solution you'd like**


**Describe alternatives you've considered**


**Additional context**

