---
title: Get Your Planet Account
---

Whenever you use the Planet SDK for Python to connect to Planet’s APIs, you’ll need to authenticate with the Planet server. To do so, you need a Planet account with your own username and password.

## Confirm your Planet account

### Sign on to Planet Explorer

If you go to <a href="https://www.planet.com/explorer/#" target="_blank" >Planet Explorer</a>, and you have an account, you’ll be prompted to enter your account username and password. That’s the same username and password you’ll use to authenticate with the Planet servers, here.

Once in Explorer, you can select the user icon in the upper right corner to go to your Account page:

<img src="../images/my-account-in-planet-explorer.png"
     style="
     display: block;
     margin-left: auto;
     margin-right: auto;
     width:50%;
     "
     alt="My Account Icon in Planet Explorer" >

### Sign up for the Planet Developer Program

If you don’t have an account, but you’d like to take our APIs for a spin and see how you might intergrate Planet into your existing geospatial workflows, you can sign up for the <a href="https://developers.planet.com/devtrial/" target="_blank">Developer Program</a>.

## Authenticating with the Planet server

After you’ve installed the Planet SDK, you can authenticate with the Planet server as outlined in the [No-Code CLI Guide](../../cli/cli-guide/#authentication)

## Next steps

Now that you have confirmed your Planet account username and password, you can take the other steps in the [Quick Start](../quick-start-guide).
