# Authentication SDK Guide

For general information on how to authenticate to Planet APIs, see the
[Authentication](https://docs.planet.com/develop/authentication/) section of Planet's
Insights Platform documentation.

See [Client Authentication Overview](../../auth/auth-overview) for an overview
of authentication to the Planet Insights Platform that is geared towards SDK
users, and includes a discussion of authentication protocols that are under
construction and available for early access to SDK users.

[Authentication with the SDK](../../auth/auth-sdk) provides a primer
on how to use the Planet SDK for Python to authenticate to Planet APIs.

----
